Class: Optify::BaseConfig

Inherits:
FromHashable
  • Object
show all
Defined in:
lib/optify_ruby/base_config.rb,
sig/optify.rbs

Overview

DEPRECATED: Use Optify::FromHashable instead. A base class for classes from configuration files. Classes that derive from this can easily be used with Optify::OptionsProvider.get_options because they will have an implementation of from_hash that works recursively. This class is a work in progress with minimal error handling and doesn't handle certain cases such as nilable types yet. It may be moved to another gem in the future.