Class: Optify::CacheOptions
- Inherits:
-
FromHashable
- Object
- FromHashable
- Optify::CacheOptions
- Defined in:
- lib/optify_ruby/implementation.rb
Overview
Options for caching. Only enabling or disabling caching is supported for now.
Options for caching. Only enabling or disabling caching is supported for now.