Class: Optify::GetOptionsPreferences
- Inherits:
-
Object
- Object
- Optify::GetOptionsPreferences
- Defined in:
- lib/optify_ruby/get_options_preferences.rb,
sig/optify.rbs
Overview
Preferences when getting options.
Instance Method Summary collapse
-
#are_configurable_strings_enabled? ⇒ Boolean
Deprecated: Use
are_configurable_values_enabled?instead. -
#are_configurable_values_enabled? ⇒ Boolean
Indicates if configurable values, such as strings and lists, are enabled.
-
#constraints=(constraints) ⇒ void
Set constraints for the current request to limit the features that can be enabled.
- #constraints_json ⇒ String?
- #constraints_json= ⇒ void
-
#disable_configurable_strings ⇒ void
Deprecated: Use
disable_configurable_valuesinstead. -
#disable_configurable_values ⇒ void
Disable configurable values which default to disabled.
-
#enable_configurable_strings ⇒ void
Deprecated: Use
enable_configurable_valuesinstead. -
#enable_configurable_values ⇒ void
Enable configurable values which default to disabled.
-
#overrides=(overrides) ⇒ void
Set overrides to apply after building the options based on the feature names.
-
#overrides? ⇒ Boolean
Indicates if overrides are set.
- #overrides_json ⇒ String?
-
#overrides_json= ⇒ void
Set overrides to apply after building the options based on the feature names.
- #skip_feature_name_conversion ⇒ Boolean
- #skip_feature_name_conversion= ⇒ void
Instance Method Details
#are_configurable_strings_enabled? ⇒ Boolean
Deprecated: Use are_configurable_values_enabled? instead.
60 |
# File 'sig/optify.rbs', line 60
def are_configurable_strings_enabled?: () -> bool
|
#are_configurable_values_enabled? ⇒ Boolean
Indicates if configurable values, such as strings and lists, are enabled. They are disabled by default.
70 |
# File 'sig/optify.rbs', line 70
def are_configurable_values_enabled?: () -> bool
|
#constraints=(constraints) ⇒ void
This method returns an undefined value.
Set constraints for the current request to limit the features that can be enabled.
9 10 11 |
# File 'lib/optify_ruby/get_options_preferences.rb', line 9 def constraints=(constraints) self.constraints_json = constraints&.to_json end |
#constraints_json ⇒ String?
83 |
# File 'sig/optify.rbs', line 83
def constraints_json: () -> String?
|
#constraints_json= ⇒ void
This method returns an undefined value.
81 |
# File 'sig/optify.rbs', line 81
def constraints_json=: (String? value) -> void
|
#disable_configurable_strings ⇒ void
This method returns an undefined value.
Deprecated: Use disable_configurable_values instead.
63 |
# File 'sig/optify.rbs', line 63
def disable_configurable_strings: () -> void
|
#disable_configurable_values ⇒ void
This method returns an undefined value.
Disable configurable values which default to disabled.
73 |
# File 'sig/optify.rbs', line 73
def disable_configurable_values: () -> void
|
#enable_configurable_strings ⇒ void
This method returns an undefined value.
Deprecated: Use enable_configurable_values instead.
66 |
# File 'sig/optify.rbs', line 66
def enable_configurable_strings: () -> void
|
#enable_configurable_values ⇒ void
This method returns an undefined value.
Enable configurable values which default to disabled.
76 |
# File 'sig/optify.rbs', line 76
def enable_configurable_values: () -> void
|
#overrides=(overrides) ⇒ void
This method returns an undefined value.
Set overrides to apply after building the options based on the feature names. Do not provide overrides when requesting cached options.
15 16 17 |
# File 'lib/optify_ruby/get_options_preferences.rb', line 15 def overrides=(overrides) self.overrides_json = overrides&.to_json end |
#overrides? ⇒ Boolean
Indicates if overrides are set.
86 |
# File 'sig/optify.rbs', line 86
def overrides?: () -> bool
|
#overrides_json ⇒ String?
98 |
# File 'sig/optify.rbs', line 98
def overrides_json: () -> String?
|
#overrides_json= ⇒ void
This method returns an undefined value.
Set overrides to apply after building the options based on the feature names. Do not provide overrides when requesting cached options.
96 |
# File 'sig/optify.rbs', line 96
def overrides_json=: (String? value) -> void
|
#skip_feature_name_conversion ⇒ Boolean
102 |
# File 'sig/optify.rbs', line 102
def skip_feature_name_conversion: () -> bool
|
#skip_feature_name_conversion= ⇒ void
This method returns an undefined value.
100 |
# File 'sig/optify.rbs', line 100
def skip_feature_name_conversion=: (bool value) -> void
|