Exception: Optify::UnknownFeatureError
- Inherits:
-
StandardError
- Object
- StandardError
- Optify::UnknownFeatureError
- Defined in:
- sig/optify.rbs
Overview
Raised when a feature name is not found in the registry.
Raised when a feature name is not found in the registry.