Class: Optify::BaseConfig

Inherits:
FromHashable
  • Object
show all
Defined in:
lib/optify_ruby/base_config.rb

Overview

DEPRECATED: Use ‘Optify::FromHashable` instead. A base class for classes from configuration files. Classes that derive from this can easily be used with `Optify::OptionsProvider.get_options` because they will have an implementation of `from_hash` that works recursively. This class is a work in progress with minimal error handling. It may be moved to another gem in the future.