Class: Optify::GetOptionsPreferences
- Inherits:
-
Object
- Object
- Optify::GetOptionsPreferences
- Defined in:
- lib/optify_ruby/get_options_preferences.rb,
sig/optify.rbs
Overview
Preferences when getting options.
Instance Method Summary collapse
-
#are_configurable_strings_enabled? ⇒ Boolean
Deprecated: Use
are_configurable_values_enabled?instead. -
#are_configurable_values_enabled? ⇒ Boolean
Indicates if configurable values, such as strings and lists, are enabled.
-
#constraints=(constraints) ⇒ void
Set constraints for the current request to limit the features that can be enabled.
- #constraints_json ⇒ String?
- #constraints_json= ⇒ void
-
#disable_configurable_strings ⇒ void
Deprecated: Use
disable_configurable_valuesinstead. -
#disable_configurable_values ⇒ void
Disable configurable values which default to disabled.
-
#enable_configurable_strings ⇒ void
Deprecated: Use
enable_configurable_valuesinstead. -
#enable_configurable_values ⇒ void
Enable configurable values which default to disabled.
-
#overrides=(overrides) ⇒ void
Set overrides to apply after building the options based on the feature names.
-
#overrides? ⇒ Boolean
Indicates if overrides are set.
- #overrides_json ⇒ String?
-
#overrides_json= ⇒ void
Set overrides to apply after building the options based on the feature names.
- #skip_feature_name_conversion ⇒ Boolean
- #skip_feature_name_conversion= ⇒ void
Instance Method Details
#are_configurable_strings_enabled? ⇒ Boolean
Deprecated: Use are_configurable_values_enabled? instead.
59 |
# File 'sig/optify.rbs', line 59
def are_configurable_strings_enabled?: () -> bool
|
#are_configurable_values_enabled? ⇒ Boolean
Indicates if configurable values, such as strings and lists, are enabled. They are disabled by default.
69 |
# File 'sig/optify.rbs', line 69
def are_configurable_values_enabled?: () -> bool
|
#constraints=(constraints) ⇒ void
This method returns an undefined value.
Set constraints for the current request to limit the features that can be enabled.
9 10 11 |
# File 'lib/optify_ruby/get_options_preferences.rb', line 9 def constraints=(constraints) self.constraints_json = constraints&.to_json end |
#constraints_json ⇒ String?
82 |
# File 'sig/optify.rbs', line 82
def constraints_json: () -> String?
|
#constraints_json= ⇒ void
This method returns an undefined value.
80 |
# File 'sig/optify.rbs', line 80
def constraints_json=: (String? value) -> void
|
#disable_configurable_strings ⇒ void
This method returns an undefined value.
Deprecated: Use disable_configurable_values instead.
62 |
# File 'sig/optify.rbs', line 62
def disable_configurable_strings: () -> void
|
#disable_configurable_values ⇒ void
This method returns an undefined value.
Disable configurable values which default to disabled.
72 |
# File 'sig/optify.rbs', line 72
def disable_configurable_values: () -> void
|
#enable_configurable_strings ⇒ void
This method returns an undefined value.
Deprecated: Use enable_configurable_values instead.
65 |
# File 'sig/optify.rbs', line 65
def enable_configurable_strings: () -> void
|
#enable_configurable_values ⇒ void
This method returns an undefined value.
Enable configurable values which default to disabled.
75 |
# File 'sig/optify.rbs', line 75
def enable_configurable_values: () -> void
|
#overrides=(overrides) ⇒ void
This method returns an undefined value.
Set overrides to apply after building the options based on the feature names. Do not provide overrides when requesting cached options.
15 16 17 |
# File 'lib/optify_ruby/get_options_preferences.rb', line 15 def overrides=(overrides) self.overrides_json = overrides&.to_json end |
#overrides? ⇒ Boolean
Indicates if overrides are set.
85 |
# File 'sig/optify.rbs', line 85
def overrides?: () -> bool
|
#overrides_json ⇒ String?
97 |
# File 'sig/optify.rbs', line 97
def overrides_json: () -> String?
|
#overrides_json= ⇒ void
This method returns an undefined value.
Set overrides to apply after building the options based on the feature names. Do not provide overrides when requesting cached options.
95 |
# File 'sig/optify.rbs', line 95
def overrides_json=: (String? value) -> void
|
#skip_feature_name_conversion ⇒ Boolean
101 |
# File 'sig/optify.rbs', line 101
def skip_feature_name_conversion: () -> bool
|
#skip_feature_name_conversion= ⇒ void
This method returns an undefined value.
99 |
# File 'sig/optify.rbs', line 99
def skip_feature_name_conversion=: (bool value) -> void
|