Class: Optify::OptionsRegistry

Inherits:
Object
  • Object
show all
Defined in:
sig/optify.rbs

Overview

A registry of features that provides configurations.

Instance Method Summary collapse

Instance Method Details

#aliasesObject

Returns All of the aliases.

Returns:

  • All of the aliases.



131
# File 'sig/optify.rbs', line 131

def aliases: () -> ::Array[String]

#buildObject

Build using just one directory.

Parameters:

  • directory

    The directory to build the provider from.

Returns:

  • The instance.



111
# File 'sig/optify.rbs', line 111

def build: (String directory) -> instance

#build_from_directoriesObject

Build from multiple directories.

Parameters:

  • directories

    The directories to build the provider from.

Returns:

  • The instance.



122
# File 'sig/optify.rbs', line 122

def build_from_directories: (::Array[String] directories) -> instance

#build_from_directories_with_schemaObject

Build from multiple directories and enforce a schema for all feature files.

Parameters:

  • directories

    The directories to build the provider from.

  • schema

    The schema to enforce.

  • schema_path (String)

Returns:

  • The instance.



128
# File 'sig/optify.rbs', line 128

def build_from_directories_with_schema: (::Array[String] directories, String schema_path) -> instance

#build_with_schemaObject

Build using just one directory and enforce a schema for all feature files.

Parameters:

  • directory

    The directory to build the provider from.

  • schema_path

    The path to the file of the schema to enforce.

Returns:

  • The instance.



117
# File 'sig/optify.rbs', line 117

def build_with_schema: (String directory, String schema_path) -> instance

#featuresObject

Returns All of the canonical feature names.

Returns:

  • All of the canonical feature names.



137
# File 'sig/optify.rbs', line 137

def features: () -> ::Array[String]

#features_and_aliasesObject

Returns All of the aliases and features.

Returns:

  • All of the aliases and features.



134
# File 'sig/optify.rbs', line 134

def features_and_aliases: () -> ::Array[String]

#features_with_metadataObject

Returns All of the keys and values for the the features.

Returns:

  • All of the keys and values for the the features.



140
# File 'sig/optify.rbs', line 140

def features_with_metadata: () -> ::Hash[String, OptionsMetadata]

#get_all_options_hash::Hash[String, untyped]

Parameters:

Returns:

  • (::Hash[String, untyped])


142
# File 'sig/optify.rbs', line 142

def get_all_options_hash: (::Array[String] feature_names, GetOptionsPreferences preferences) -> ::Hash[String, untyped]

#get_all_options_jsonString

Parameters:

Returns:

  • (String)


144
# File 'sig/optify.rbs', line 144

def get_all_options_json: (::Array[String] feature_names, GetOptionsPreferences preferences) -> String